==> estateplat-common-1.2.3-20180919.074355-188-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXzyzLw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-1-14
 * @description 不动产限制验证例外表
 */
@Table(name = "bdc_xzyz_lw")
public class BdcXzyzLw {
    @Id
    private String lwid;
    private String ip;
    private String czryid;
    private Date czsj;
    private String lwlx;
    private String wiid;
    private String xzwh;
    private String lwyy;

    public String getLwid() {
        return lwid;
    }

    public void setLwid(String lwid) {
        this.lwid = lwid;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getCzryid() {
        return czryid;
    }

    public void setCzryid(String czryid) {
        this.czryid = czryid;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getLwlx() {
        return lwlx;
    }

    public void setLwlx(String lwlx) {
        this.lwlx = lwlx;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getXzwh() {
        return xzwh;
    }

    public void setXzwh(String xzwh) {
        this.xzwh = xzwh;
    }

    public String getLwyy() {
        return lwyy;
    }

    public void setLwyy(String lwyy) {
        this.lwyy = lwyy;
    }
}

==> estateplat-common-1.2.4-20210716.064322-813-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXzyzLw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-1-14
 * @description 不动产限制验证例外表
 */
@Table(name = "bdc_xzyz_lw")
public class BdcXzyzLw {
    @Id
    private String lwid;
    private String ip;
    private String czryid;
    private Date czsj;
    private String lwlx;
    private String wiid;
    private String xzwh;
    private String lwyy;
    private String xzlx;//限制类型

    public String getXzlx() {
        return xzlx;
    }

    public void setXzlx(String xzlx) {
        this.xzlx = xzlx;
    }

    public String getLwid() {
        return lwid;
    }

    public void setLwid(String lwid) {
        this.lwid = lwid;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getCzryid() {
        return czryid;
    }

    public void setCzryid(String czryid) {
        this.czryid = czryid;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getLwlx() {
        return lwlx;
    }

    public void setLwlx(String lwlx) {
        this.lwlx = lwlx;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getXzwh() {
        return xzwh;
    }

    public void setXzwh(String xzwh) {
        this.xzwh = xzwh;
    }

    public String getLwyy() {
        return lwyy;
    }

    public void setLwyy(String lwyy) {
        this.lwyy = lwyy;
    }
}
